@@ -54,6 +54,34 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ClearLaunchConfigurationAttributes(self, request):
+        """本接口（ClearLaunchConfigurationAttributes）用于将启动配置内的特定属性完全清空。
+
+        :param request: Request instance for ClearLaunchConfigurationAttributes.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ClearLaunchConfigurationAttributesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ClearLaunchConfigurationAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ClearLaunchConfigurationAttributes", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ClearLaunchConfigurationAttributesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CompleteLifecycleAction(self, request):
         """本接口（CompleteLifecycleAction）用于完成生命周期动作。
 
@@ -835,6 +863,7 @@ class AutoscalingClient(AbstractClient):
         """本接口（DetachInstances）用于从伸缩组移出 CVM 实例，本接口不会销毁实例。
         * 如果移出指定实例后，伸缩组内处于`IN_SERVICE`状态的实例数量小于伸缩组最小值，接口将报错
         * 如果伸缩组处于`DISABLED`状态，移出操作不校验`IN_SERVICE`实例数量和最小值的关系
+        * 对于伸缩组配置的 CLB，实例在离开伸缩组时，AS 会进行解挂载动作
 
         :param request: Request instance for DetachInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.DetachInstancesRequest`
@@ -1183,6 +1212,7 @@ class AutoscalingClient(AbstractClient):
         """本接口（RemoveInstances）用于从伸缩组删除 CVM 实例。根据当前的产品逻辑，如果实例由弹性伸缩自动创建，则实例会被销毁；如果实例系创建后加入伸缩组的，则会从伸缩组中移除，保留实例。
         * 如果删除指定实例后，伸缩组内处于`IN_SERVICE`状态的实例数量小于伸缩组最小值，接口将报错
         * 如果伸缩组处于`DISABLED`状态，删除操作不校验`IN_SERVICE`实例数量和最小值的关系
+        * 对于伸缩组配置的 CLB，实例在离开伸缩组时，AS 会进行解挂载动作
 
         :param request: Request instance for RemoveInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.RemoveInstancesRequest`
